@@ -1,7 +1,9 @@
 """Scaffolding helpers for Vega CLI."""
 
 from .fastapi import create_fastapi_scaffold
+from .sqlalchemy import create_sqlalchemy_scaffold
 
 __all__ = [
     "create_fastapi_scaffold",
+    "create_sqlalchemy_scaffold",
 ]
